==> mastapy-14.0.0b1.tar.gz: mastapy-14.0.0b1/mastapy/_private/_internal/implicit/overridable/diameter_series.py <==
"""Implementations of 'Overridable' in Python.

As Python does not have an implicit operator, this is the next
best solution for implementing these types properly.
"""
from __future__ import annotations

from enum import Enum
from typing import TYPE_CHECKING

from mastapy._private.bearings.bearing_designs.rolling import _2204
from mastapy._private._internal import mixins
from mastapy._private._internal.python_net import python_net_import

_OVERRIDABLE = python_net_import("SMT.MastaAPI.Utility.Property", "Overridable")

if TYPE_CHECKING:
    from typing import Type, Any, TypeVar

    Self = TypeVar("Self", bound="Overridable_DiameterSeries")


__docformat__ = "restructuredtext en"
__all__ = ("Overridable_DiameterSeries",)


class Overridable_DiameterSeries(mixins.OverridableMixin, Enum):
    """Overridable_DiameterSeries

    A specific implementation of 'Overridable' for 'DiameterSeries' types.
    """

    __qualname__ = "DiameterSeries"

    @classmethod
    def wrapper_type(cls: "Type[Overridable_DiameterSeries]") -> "Any":
        """Pythonnet type of this class.

        Note:
            This property is readonly.

        Returns:
            Any
        """
        return _OVERRIDABLE

    @classmethod
    def wrapped_type(cls: "Type[Overridable_DiameterSeries]") -> "_2204.DiameterSeries":
        """Wrapped Pythonnet type of this class.

        Note:
            This property is readonly

        Returns:
            _2204.DiameterSeries
        """
        return _2204.DiameterSeries

    @classmethod
    def implicit_type(cls: "Type[Overridable_DiameterSeries]") -> "Any":
        """Implicit Pythonnet type of this class.

        Note:
            This property is readonly.

        Returns:
            Any
        """
        return _2204.DiameterSeries.type_()

    @property
    def value(self: "Self") -> "_2204.DiameterSeries":
        """mastapy._private.bearings.bearing_designs.rolling.DiameterSeries

        Note:
            This property is readonly.
        """
        return None

    @property
    def overridden(self: "Self") -> "bool":
        """bool

        Note:
            This property is readonly.
        """
        return None

    @property
    def override_value(self: "Self") -> "_2204.DiameterSeries":
        """mastapy._private.bearings.bearing_designs.rolling.DiameterSeries

        Note:
            This property is readonly.
        """
        return None

    @property
    def calculated_value(self: "Self") -> "_2204.DiameterSeries":
        """mastapy._private.bearings.bearing_designs.rolling.DiameterSeries

        Note:
            This property is readonly.
        """
        return None

==> mastapy-14.1.0b2.tar.gz: mastapy-14.1.0b2/mastapy/_private/_internal/implicit/overridable/diameter_series.py <==
"""Implementations of 'Overridable' in Python.

As Python does not have an implicit operator, this is the next
best solution for implementing these types properly.
"""

from __future__ import annotations

from enum import Enum
from typing import TYPE_CHECKING

from mastapy._private._internal import mixins
from mastapy._private._internal.python_net import python_net_import
from mastapy._private.bearings.bearing_designs.rolling import _2219

_OVERRIDABLE = python_net_import("SMT.MastaAPI.Utility.Property", "Overridable")

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    Self = TypeVar("Self", bound="Overridable_DiameterSeries")


__docformat__ = "restructuredtext en"
__all__ = ("Overridable_DiameterSeries",)


class Overridable_DiameterSeries(mixins.OverridableMixin, Enum):
    """Overridable_DiameterSeries

    A specific implementation of 'Overridable' for 'DiameterSeries' types.
    """

    __qualname__ = "DiameterSeries"

    @classmethod
    def wrapper_type(cls: "Type[Overridable_DiameterSeries]") -> "Any":
        """Pythonnet type of this class.

        Note:
            This property is readonly.

        Returns:
            Any
        """
        return _OVERRIDABLE

    @classmethod
    def wrapped_type(cls: "Type[Overridable_DiameterSeries]") -> "_2219.DiameterSeries":
        """Wrapped Pythonnet type of this class.

        Note:
            This property is readonly

        Returns:
            _2219.DiameterSeries
        """
        return _2219.DiameterSeries

    @classmethod
    def implicit_type(cls: "Type[Overridable_DiameterSeries]") -> "Any":
        """Implicit Pythonnet type of this class.

        Note:
            This property is readonly.

        Returns:
            Any
        """
        return _2219.DiameterSeries.type_()

    @property
    def value(self: "Self") -> "_2219.DiameterSeries":
        """mastapy.bearings.bearing_designs.rolling.DiameterSeries

        Note:
            This property is readonly.
        """
        return None

    @property
    def overridden(self: "Self") -> "bool":
        """bool

        Note:
            This property is readonly.
        """
        return None

    @property
    def override_value(self: "Self") -> "_2219.DiameterSeries":
        """mastapy.bearings.bearing_designs.rolling.DiameterSeries

        Note:
            This property is readonly.
        """
        return None

    @property
    def calculated_value(self: "Self") -> "_2219.DiameterSeries":
        """mastapy.bearings.bearing_designs.rolling.DiameterSeries

        Note:
            This property is readonly.
        """
        return None
